@@ -26,7 +26,6 @@ this._GLOBAL_sask = None
 this._GLOBAL_client_id = None
 this._GLOBAL_client_secret = None
 this._GLOBAL_ti = None
-this._GLOBAL_cn = None
 
 # Name of the URL
 this._GLOBAL_url = None
@@ -36,9 +35,36 @@ this._GLOBAL_sso_url = None
 # directory for token 
 this._GLOBAL_token_outh2 = None
 
-def update(ti, cn, access_token, expires_in,refresh_token,token_type,start_session,session_expire,saak,sask,client_id,client_secret):
+def configfile(filename):
+    with open(filename) as file:
+        config_json = json.load(file)
+                
+    if all (k in config_json for k in ('url','ionfile','program','method','inputfile')):
+        typ = "L"
+        url = config_json['url']
+        ionfile = config_json['ionfile']
+        program = config_json['program']
+        method = config_json['method']
+        inputfile = config_json['inputfile']
+        outputfile = config_json['outputfile']
+    
+        
+    else:
+        print ("JSON File wrong config")
+        sys.exit(0)
+    
+    if "start" in config_json:
+            start = config_json["start"]
+    else:
+        start = None
+    if "end" in config_json:
+        end = config_json["end"]
+    else:
+        end = None
+
+
+def update(ti,access_token, expires_in,refresh_token,token_type,start_session,session_expire,saak,sask,client_id,client_secret):
     this._GLOBAL_ti = ti
-    this._GLOBAL_cn = cn
     this._GLOBAL_access_token = access_token
     this._GLOBAL_expires_in = expires_in
     this._GLOBAL_refresh_token = refresh_token
@@ -62,7 +88,7 @@ def load_config(IONFile):
             print ("Error in ION file - cn")            
             sys.exit(0)
         else:
-            this._GLOBAL_cn = data["cn"]
+            this._GLOBAL_ti = data["cn"]
 
         this._GLOBAL_client_id = data["ci"] 
         this._GLOBAL_client_secret = data["cs"] 
@@ -109,14 +135,15 @@ def login():
     sask = this._GLOBAL_sask
     client_id = this._GLOBAL_client_id
     ti = this._GLOBAL_ti
-    cn = this._GLOBAL_cn
     client_secret = this._GLOBAL_client_secret
   
     session_expire = addSecs(start_session, expires_in)
     #session_expire = addSecs(start_session, 60)  
 
     
-    update(ti, cn, access_token, expires_in, refresh_token, token_type,start_session,session_expire,saak,sask,client_id,client_secret)
+    update(ti,access_token, expires_in, refresh_token, token_type,start_session,session_expire,saak,sask,client_id,client_secret)
+
+
 
     return r
 
@@ -220,5 +247,3 @@ def header():
     return headers
 
 
-def get_base_url():
-    return this._GLOBAL_url + '/' + this._GLOBAL_ti
